.. _torchani-user-guide:

.. currentmodule:: torchani

User guide
==========

ANI models expects all coordinates to be in Angstrom, all energies to be in Hartree and
forces in Hartree/Angstrom.

.. toctree::
    :maxdepth: 1
    :titlesonly:
    :caption: Getting started

    examples_autogen/fundamentals.rst
    migrating-to-2.rst

.. toctree::
    :maxdepth: 1
    :titlesonly:
    :caption: Molecular dynamics and second-order properties

    examples_autogen/ase_interface.rst
    examples_autogen/vibration_analysis.rst

.. toctree::
    :maxdepth: 1
    :titlesonly:
    :caption: Extending TorchANI

    examples_autogen/dispersion_potential.rst
    examples_autogen/repulsive_potential.rst
    examples_autogen/extending_aev.rst

.. toctree::
    :maxdepth: 1
    :titlesonly:
    :caption: Manipulating ANI Datasets

    examples_autogen/datasets_simple_usage.rst
    examples_autogen/datasets_advanced_usage.rst

.. toctree::
    :maxdepth: 1
    :titlesonly:
    :caption: Training and deploying NN-IPs

    examples_autogen/training.rst
    examples_autogen/just_in_time_compilation.rst

.. toctree::
    :maxdepth: 1
    :titlesonly:
    :caption: Working with legacy NeuroChem files

    examples_autogen/neurochem_loading.rst
